# --- Preprocessing --------------------------------------------------#
#
# The data is read into the data frame "snarc_raw" which contains three
# variables: Subject, Number, and SNARC. We will factorize the variable
# Subject to pre-allocate an empty array (snarc_coefs) that is going to
# be filled with individual regression slopes.
#
# Data import (file has to be located in the working directory):
snarc_raw <- read.table("SNARC_Raw.txt",header = TRUE, sep = "\t")

# Factorization:
snarc_raw$Subject <- as.factor(snarc_raw$Subject)

# Pre-allocation:
snarc_coefs <- rep(NA,1,length(levels(snarc_raw$Subject)))
# --------------------------------------------------------------------#



# --- Perform participant-wise regressions ---------------------------#
#
# We then use the for-function to loop through the data frame. The loop
# index i is composed of the levels of Subject. Each iteration consists
# of four separate steps: First, the data of the subject in question is
# stored in a temporary data frame (snarc_tmp) to be analyzed separate-
# ly. Secondly, the SNARC effect is regressed on the variable Number by
# using the lm-function. The output of the regression analysis is saved
# in the variable reg_result. Thirdly, the coef-function can be used to
# accesses the coefficients of reg_results directly. The resulting vec-
# tor tmp_coef contains two number: the intercept at position 1 and the
# slope at position 2. Finally, the slope is sent to the summary vector
# snarc_coefs. 
for (i in levels(snarc_raw$Subject)) {
  # Create temporary data frame:
  snarc_tmp  <- snarc_raw[snarc_raw$Subject==i,]
  # Perform regression:
  reg_result <- lm(snarc_tmp$SNARC ~ snarc_tmp$Number)
  # Get coefficient:
  tmp_coef   <- coef(reg_result)
  # Store coefficient:
  snarc_coefs[as.numeric(i)] <- tmp_coef[2]
}

# Display results:
snarc_coefs
# --------------------------------------------------------------------#